This function converts all text files in a directory to CSV format.
convert_all_directory_files_as_csv(extract_dir, delete_text_files = FALSE)The directory containing the text files to be converted.
Logical indicating whether to delete the original text files after conversion.