This function downloads a zip file containing NDC (National Drug Code) text files from a specified URL, extracts the files to a directory, converts them to CSV format, and optionally deletes the original text files.
download_ndc_files_as_csv(
zip_file_url = "https://www.accessdata.fda.gov/cder/ndctext.zip",
zip_file_name = "ndctext.zip",
extract_dir = "inst/extdata/ndctext"
)The URL of the zip file containing NDC text files to download.
The name of the downloaded zip file.
The directory where the NDC text files will be extracted.