View source: R/convert_antibiotics.R
| ndc_is_antimicrobial | R Documentation |
Function to check input 'ndc' code is belongs to any Antimicrobial or not.
ndc_is_antimicrobial(ndc,
class_names,
include_missing_NDCs = TRUE)
ndc |
A vector containing ndc codes. Will be coerced to character vector. |
class_names |
A vector containing antibacterial classes
|
include_missing_NDCs |
includes a hardcoded database of NDCs that are present in MIMIC-IV but not in NDC database. |
ndc_is_antimicrobial
#' Note: Certain medications, such as Rifaximin, may not be considered antibiotics for all purposes despite their classification. Specific cases should be handled based on context and requirements.
Boolean vector for whether input ndc code corresponds to an antimicrobial
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.