Function to check input 'ndc' code is belongs to any Antimicrobial or not.
ndc_is_antimicrobial(ndc,
class_names,
include_missing_NDCs = TRUE)Boolean vector for whether input ndc code corresponds to an antimicrobial
A vector containing ndc codes. Will be coerced to character vector.
A vector containing antibacterial classes
eg: c("antimicrobial", "antibacterial")
includes a hardcoded database of NDCs that are present in MIMIC-IV but not in NDC database.
ndc_is_antimicrobial
#' Note: Certain medications, such as Rifaximin, may not be considered antibiotics for all purposes despite their classification. Specific cases should be handled based on context and requirements.